Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(544)

Unified Diff: ui/base/win/tsf_text_store.cc

Issue 10942005: Add TS_SS_TRANSITORY flag to the return value of TsfTextStore::GetStatus. (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | ui/base/win/tsf_text_store_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/base/win/tsf_text_store.cc
diff --git a/ui/base/win/tsf_text_store.cc b/ui/base/win/tsf_text_store.cc
index 61dbdc082afdfe501672f5b21a5214149da9868e..ae876f70039b1524e91e3a8ad63e9a127ea6cef9 100644
--- a/ui/base/win/tsf_text_store.cc
+++ b/ui/base/win/tsf_text_store.cc
@@ -189,8 +189,8 @@ STDMETHODIMP TsfTextStore::GetStatus(TS_STATUS* status) {
return E_INVALIDARG;
status->dwDynamicFlags = 0;
- // We don't support hidden text.
- status->dwStaticFlags = TS_SS_NOHIDDENTEXT;
+ // We use transitory contexts and we don't support hidden text.
+ status->dwStaticFlags = TS_SS_TRANSITORY | TS_SS_NOHIDDENTEXT;
return S_OK;
}
« no previous file with comments | « no previous file | ui/base/win/tsf_text_store_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698